;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "browse-kill-ring" "20251208.1041"
  "Interactively insert items from kill-ring."
  ()
  :url "https://github.com/browse-kill-ring/browse-kill-ring"
  :commit "26ea5759c996e782abadc61b85c5f9324d1d1dae"
  :revdesc "26ea5759c996"
  :keywords '("convenience")
  :authors '(("Colin Walters" . "walters@verbum.org"))
  :maintainers '(("browse-kill-ring" . "browse-kill-ring@tonotdo.com")))
